This function processes a list representing a function input. If the function
is supplied with an argument, the argument should be specified in the form
list(c(fun, arg=x)). The function returns the input function unchanged if
no arguments are provided or wraps the function with its arguments using
purrr::partial if arguments are present.
Value
A function with arguments wrapped using purrr::partial if arguments
are provided; otherwise, returns the function unchanged.